==> GeneticsBase_1.0.0.tar.gz: GeneticsBase/R/ped2geneSet.R <==
ped2geneSet <- function(ped, 
                        markerNames,
                        columns=c("family", "pid", "father", "mother", 
                                  "sex", "affected"), 
                        quiet=FALSE,
                        filename)
{
  len <- length(columns)
  if(len==0)
    stop("'ped' doesn't contain sampleInfo!\n")

  ## extract sample information  
  sampleInfo <- ped[, 1:len]
  colnames(sampleInfo) <- columns
  sampleInfo <- as.data.frame(sampleInfo)

  ## extract genotype information
  geneInfo <- ped[, -c(1:len)]
  
  ## Construct code Matrix and translatioon Table.
  ## rows of callCodes are markers
  ## columns of callCodes are samples
  callCodes <- matrix(ncol=nrow(geneInfo), nrow=length(markerNames))
  transTables <- as.list(vector(length=length(markerNames)))

  ##FIXME:  Instead of creating one TransTable for each marker,
  ##        create one for each *unique* set of marker alleles.
  
  for(i in 1:length(markerNames))
  {
    ## Show how may markers are done, by 100's.
    if(!quiet && (i%%100==0) )
      {
        cat(i, ' ', sep='')
        flush(stdout())
      }  
    
    ## Start new line every 10th set of 100 .
    if(!quiet && (i%%1000-1==0) )
      {
        cat("\n")
        flush(stdout())
      } 

    a1col <- i*2-1
    a2col <- i*2
    pairs <- factor(
                    paste(
                          geneInfo[, a1col], 
                          geneInfo[, a2col], 
                          sep="/")
                    )
    
    uniquepairs <- levels(pairs)
    callCodes[i, ] <- as.numeric(pairs)
    transTables[[i]] <- cbind(uniquepairs, 
                              do.call("rbind", 
                                      strsplit(uniquepairs, '/')
                                      )
                              )
    colnames(transTables[[i]]) <- c("levels", "allele.1", "allele.2")
  }

  colnames(callCodes) <- paste(ped[, 1], ped[, 2], sep=".")
  rownames(callCodes) <- markerNames
  names(transTables) <- markerNames

  markerInfo <- makeMarkerInfo( markerNames, markerNames)
  
  cs  <- geneSet(
                 callCodes = callCodes, 
                 transTables = transTables, 
                 sampleInfo = sampleInfo, 
                 missingCodes = "0",
                 notes = paste("Loaded from file `", filename, "'.", sep=''), 
                 markerInfo = markerInfo, 
                 studyInfo=list(),
                 description="",
                 phase = list(FALSE), 
                 ploidy = 2
                 )
  cs
}

==> GeneticsBase_1.6.0.tar.gz: GeneticsBase/R/ped2geneSet.R <==
ped2geneSet <- function(pedObj, quiet=FALSE)
{
  ped<-pedObj$ped
  columns<-pedObj$columns
  markerNames<-pedObj$markerNames
  filename<-pedObj$fileName

  len <- length(columns)
  if(len==0)
    stop("'ped' doesn't contain sampleInfo!\n")

  ## extract sample information  
  sampleInfo <- ped[, 1:len,drop=FALSE]
  colnames(sampleInfo) <- columns
  sampleInfo <- as.data.frame(sampleInfo)

  ## extract genotype information
  geneInfo <- ped[, -c(1:len),drop=FALSE]
  
  ## Construct code Matrix and translatioon Table.
  ## rows of callCodes are markers
  ## columns of callCodes are samples
  callCodes <- matrix(ncol=nrow(geneInfo), nrow=length(markerNames))
  transTables <- as.list(vector(length=length(markerNames)))

  ##FIXME:  Instead of creating one TransTable for each marker,
  ##        create one for each *unique* set of marker alleles.
  
  for(i in 1:length(markerNames))
  {
    ## Show how may markers are done, by 100's.
    if(!quiet && (i%%100==0) )
      {
        cat(i, ' ', sep='')
        flush(stdout())
      }  
    
    ## Start new line every 10th set of 100 .
    if(!quiet && (i%%1000-1==0) )
      {
        cat("\n")
        flush(stdout())
      } 

    a1col <- i*2-1
    a2col <- i*2
    pairs <- factor(
                    paste(
                          geneInfo[, a1col], 
                          geneInfo[, a2col], 
                          sep="/")
                    )
    
    uniquepairs <- levels(pairs)
    callCodes[i, ] <- as.numeric(pairs)
    transTables[[i]] <- cbind(uniquepairs, 
                              do.call("rbind", 
                                      strsplit(uniquepairs, '/')
                                      )
                              )
    colnames(transTables[[i]]) <- c("levels", "allele.1", "allele.2")
  }

  colnames(callCodes) <- paste(ped[, 1], ped[, 2], sep=".")
  rownames(callCodes) <- markerNames
  names(transTables) <- markerNames

  markerInfo <- makeMarkerInfo( markerNames, markerNames)
  
  cs  <- geneSet(
                 callCodes = callCodes, 
                 transTables = transTables, 
                 sampleInfo = sampleInfo, 
                 missingCodes = "0",
                 notes = paste("Loaded from file `", filename, "'.", sep=''), 
                 markerInfo = markerInfo, 
                 studyInfo=list(),
                 description="",
                 phase = list(FALSE), 
                 ploidy = 2
                 )
  cs
}
